module.exports = defineTest({
	description: 'tracks literal values across return expressions'
});
